# A Simple Text Recording Assistant (ASTRA): Special Edition
![Release](https://github.com/anoaky/AstraSE/actions/workflows/publish-stable.yml/badge.svg) ![PyPI](https://github.com/anoaky/AstraSE/actions/workflows/publish-pypi.yml/badge.svg)

Readme in progress.